@echo off


rem ===========================================================================
rem
rem Script Name:        UGS_UPDATE.BAT
rem
rem This script updates files for NX products.
rem The script should be run from a command prompt window.
rem
rem ===========================================================================
rem
rem Copyright (c) 1995-2004 UGS Corp. All Rights Reserved
rem
rem ===========================================================================
rem Revision History:
rem
rem RELEASE   AUTHOR      DATE     COMMENT
rem =======   ======      =======  =======
rem 2.0.1.1   R. Baxter   15SEP03  Initial version for NX 2.0.1 
rem 2.0.1.2   R. Baxter   15OCT03  Initial version for NX 2.0.1 
rem 2.0.2.1   R. Baxter   28JAN04  Multiple changes for sfx image support.
rem 2.0.2.2   R. Baxter   02FEB04  Chng to support both xcopy or sfx images.
rem 2.0.3.1   R. Baxter   23MAR04  Added custom action to run fixreg.vbs
rem 2.0.4.1   R. Baxter   23APR04  No change.
rem 2.0.4.2   R. Baxter   29JUN04  No change.
rem 2.0.5.1   R. Baxter   24AUG04  Add 4 digit rev ck and other chngs for MP's.
rem 2.0.5.1   R. Baxter   16SEP04  Chng to explicit cscript.exe for fixreg.vbs
rem 2.0.5.1   R. Baxter   21SEP04  Add /d switch support.
rem ===========================================================================





rem ===========================================================================
rem  Modified version of original UGS script from version NX2.0.6.2
rem   Added the filling of the error variables to track them in the calling script
rem ===========================================================================
REM added code and text for success-check
set UG_UPD_ERR_CODE=-1
set UG_UPD_ERR_TEXT=
rem ===========================================================================





rem Initial setup and checks. _______________________________________________

rem Version control variables. 

rem Version number of this Maintenance Release (MR) or Maintenance Pack (MP).
set VERSION=2.0.6.2

rem Minimum installed NX version required. MR's use the Base release num, but
rem the version & min_version must be equal for MP's.
set MIN_VERSION=2.0.6.2

rem Version title. Displayed text only. may be different than version num.
set TEXT_VERSION=2.0.6.2 Maintenance Pack 5

rem Max_version must always be set to version to prevent version downgrades.
set MAX_VERSION=%VERSION%

rem Set the system path for this script.
set PATH=%PATH%;%SystemRoot%\system32

rem Begin initial checks. ____________________________________________________

rem Make sure user is installing on correct hardware platform.  x86 or IA64.
set REQUIRED_PLAT=x86
set ACTUAL_PLAT=%PROCESSOR_ARCHITECTURE%
if not "%ACTUAL_PLAT%" == "%REQUIRED_PLAT%" goto wrong_platform
rem End platform check. ______________________________________________________

rem Check for a UGII_BASE_DIR environment variable, if not set abort.
if not defined UGII_BASE_DIR goto no_base_dir
rem End env var check. _______________________________________________________

rem Next, set a var with a short name to make the scripting easier. And also, 
rem strip any quotation marks. The :"= operator strips out the quotes. 
rem Then we can use BASE (with or without quotes) as needed.
set BASE=%UGII_BASE_DIR:"=%
rem End %BASE% setup. ________________________________________________________

rem Check if UGII_BASE_DIR (using %BASE%) actually exists, if not, abort.
if not exist "%BASE%" goto no_ug
rem End %BASE% dir check. ____________________________________________________

rem Check that we can find env_print in %BASE%.
if not exist "%BASE%"\ugii\env_print.exe goto no_env_print
rem End env_print check. _____________________________________________________

rem Check the 4 digit version number. Added NX20501.
set REV=""
rem First set NX_REV from the output of env_print -n.
for /f "tokens=*" %%I in (' "%BASE%\ugii\env_print" -n ') do set NX_REV=%%I
rem Next strip off any letters or spaces.
set NX_REV=%NX_REV:V=% 
set NX_REV=%NX_REV:NX=% 
set NX_REV=%NX_REV: =%
rem Now compare NX_REV to the minimum and maximum versions. 
if %NX_REV% GTR %MAX_VERSION% goto wrong_ug_version
if %NX_REV% LSS %MIN_VERSION% goto wrong_ug_version
rem End Version checks._______________________________________________________

rem Check for /v or /d switches. The /d switch added in V2.0.5.1
rem
rem Check for the verbose switch.  Default is set to no messages.
rem The Q_SWT is used by xcopy and V_SWT is used by sfx images.
rem Defaults are set to quiet or silent.
set Q_SWT=/q  &  set V_SWT=-silent
if /I (%1) == (-v) ( set Q_SWT=/f & set V_SWT= )
if /I (%1) == (/v) ( set Q_SWT=/f & set V_SWT= )
if /I (%1) == (v)  ( set Q_SWT=/f & set V_SWT= )
if /I (%2) == (-v) ( set Q_SWT=/f & set V_SWT= )
if /I (%2) == (/v) ( set Q_SWT=/f & set V_SWT= )
if /I (%2) == (v)  ( set Q_SWT=/f & set V_SWT= )
rem
rem Check for the (/d) switch.  If set we dont ask questions. V2.0.5.1
set D_SWT=
if /I (%1) == (-d)   set D_SWT=/d
if /I (%1) == (/d)   set D_SWT=/d
if /I (%1) == (d)    set D_SWT=/d
if /I (%2) == (-d)   set D_SWT=/d
if /I (%2) == (/d)   set D_SWT=/d
if /I (%2) == (d)    set D_SWT=/d
rem End switches checks. ____________________________________________________


rem MAIN ____________________________________________________________________


rem All checks look o.k. give a startup message if not turned of by /d. 
if "%D_SWT%" == "/d" (
cls
  echo Installing NX %TEXT_VERSION% files 
  echo in: %BASE%
  echo.
) else (
  cls
  echo This script will install NX %TEXT_VERSION% files 
  echo in: %BASE% 
  echo.
  echo Enter Cntrl-C to abort or & pause
  echo. & echo. 
)
rem _________________________________________________________________________


rem Stop all UG services. ______________________________________________________
rem We can't replace files if they're running.
echo Stopping NX services . . .
set ERRORLEVEL=0
net stop "Unigraphics License Server (uglmd)" >NUL 2>&1
net stop ugiipqd >NUL 2>&1
echo.
rem _________________________________________________________________________


rem Perform Pre-Copy Custom Actions _________________________________________
rem
rem Make sure we have an install folder. Needed for fixreg.vbs. added V2.0.3.1
mkdir "%BASE%"\install >NUL 2>&1
rem
rem End of Custom Actions ___________________________________________________


rem Copy the kits. __________________________________________________________
rem This routine makes a list of all the subdirectories in the QRM/IRM 
rem directory then calls the copy_kits subroutine and passes the kit name.
echo.
echo Copying files. Please wait . . .
echo. & echo.
rem Reset the COPY_ERRORS flag
set COPY_ERRORS=
rem
rem Make a list of all the kits then call copy_kits for each one.
for /F %%K in ('dir /b *') do call :copy_kits %%K
rem End of Copy the kits. ___________________________________________________


rem Perform Post-Copy Custom Actions ________________________________________
rem
rem Run fixreg.vbs to correct registry entries that needed quotes. V2.0.3.1
rem As of V2.0.5.1 Execute cscript.exe rather than rely on the .vbs file 
rem association cuz if it fails it will pop up "open with" window. Also
rem check cscript return status to give a helpful error message. V2.0.5.1
rem
if exist "%BASE%"\install\fixreg.vbs (
   echo Running fixreg.vbs . . . 
   cscript.exe /nologo "%BASE%"\install\fixreg.vbs >NUL 2>&1 || (
     echo ERROR: could not successfully run fixreg.vbs
     echo    The Registry entry for the .vbs file association may be incorrect.
     echo    To view the error, run the following command line:
     echo    cscript "%BASE%"\install\fixreg.vbs
   )
   echo.
)
rem
rem End of Custom Actions ___________________________________________________


rem Re-start UG services ____________________________________________________
echo.
echo Restarting NX services . . .
echo.
net start "Unigraphics License Server (uglmd)" > NUL 2>&1
net start ugiipqd > NUL 2>&1
rem _________________________________________________________________________


rem Set UG file permissions. _________________________________________________
rem
echo.
echo Setting file permissions . . .
if "%COMPUTERNAME%" == "%USERDOMAIN%" (
   cacls "%BASE%" /t /e /c /p ADMINISTRATOR:F ADMINISTRATORS:F EVERYONE:R > NUL
) else (
   cacls "%BASE%" /t /e /c /p ADMINISTRATOR:F ADMINISTRATORS:F "DOMAIN ADMINS":F     EVERYONE:R > NUL
)
rem _________________________________________________________________________


rem Set Registry requirements. ______________________________________________
rem
if exist "%BASE%"\install\DeleteRegDBValue.exe (
   echo Updating Registry . . .  &  echo.
   "%BASE%"\install\DeleteRegDBValue.exe "SOFTWARE\Unigraphics Solutions\Installed Applications" "%BASE%"  >NUL 2>&1
)
rem _________________________________________________________________________


rem Give a completion message. ______________________________________________
rem Check for any xcopy errors and give the appropriate message.
echo.
if defined COPY_ERRORS (
   echo ERROR:  One or more files failed to update. These errors may be caused
   echo by a sharing violation on open files in the destination directory.
   echo Review the output text for specific file information.
   echo.
   echo Close all files in the destination and re-run ugs_update.
   echo.
   echo The following kits had update errors:
   echo %COPY_ERRORS%

REM added code for success-check
set UG_UPD_ERR_TEXT=The following kits had update errors: %NX_REV%

) else (
   echo.
   echo DONE. %0 has completed successfully !
)


rem This the LOGICAL END of the SCRIPT.
echo.
goto end_update
rem _________________________________________________________________________



rem _______ SUBROUTINES _____________________________________________________


rem Copy kits. ______________________________________________________________
rem This is where we actually do the copies or extractions.
rem Updated NX 2.0.2.1 28JAN04 to use sfx images instead of xcopy.
rem Updated NX 2.0.2.2 02FEB04 to use sfx images or xcopy.

:copy_kits

  rem set KIT var to arg1 to get a recognizable var name.
  set KIT=%1%

  rem check for a null argument and if so just return.
  if not defined KIT goto :EOF

  rem set DIR to just the kit name. strip off the extension.
  set DIR=%~n1

  rem set EXT to just the extension. strip off the kit name.
  set EXT=%~x1

  rem now check if there is a kit folder in base dir if not just return.
  if not exist "%BASE%"\%DIR%  goto :EOF

  rem Now do the sfx or xcopy. If arg1 had an extension do the sfx method.
  rem if arg1 had no extension just do a regular xcopy.
  if defined EXT (
     echo Updating files in %BASE%\%DIR% . . .
     rem Must remove any read-only attributes cuz sfx wont overwrite.
     attrib -R "%BASE%"\%DIR%\* /S /D > NUL
     rem New method for 2.0.2.1 using self extracting files.
     %KIT% -extract -directories -overwrite %V_SWT% "%BASE%"
     if errorlevel 1 (
        set COPY_ERRORS=%COPY_ERRORS% %DIR%
        echo ERROR updating %DIR%
     ) else (
        echo Updated %DIR%
     )
  rem if no extension so use the old xcopy method.
  ) else (
     echo Updating files in %BASE%\%DIR% . . .
     xcopy  /i/e/k/h/r/y%Q_SWT%  %KIT%  "%BASE%"\%KIT%
     if errorlevel 1 (
        set COPY_ERRORS=%COPY_ERRORS% %DIR%
        echo ERROR updating %DIR%
     ) else (
        echo Updated %DIR%
     )
  )
  echo. & echo. 

goto :EOF
rem ________________________________________________________________________



rem Error handlers __________________________________________________________ 

:no_base_dir
cls
echo.
echo The NX environment variable %%UGII_BASE_DIR%% is not defined.
echo Please install NX before running %0.
echo.

REM added code for success-check
set UG_UPD_ERR_TEXT=Error in UG-Update: UGII_BASE_DIR is not defined.
goto end_update

:no_env_print
cls
echo.
echo The folder defined by the variable %%UGII_BASE_DIR%% does not
echo appear to contain the 'env_print.exe' program needed by %0.
echo.
echo Check that %BASE%\ugii\env_print.exe exists before running %0.
echo.

REM added code for success-check
set UG_UPD_ERR_TEXT=Error in UG-Update: No env_print.exe found.
goto end_update

:no_ug
cls
echo.
echo NX does not appear to be installed on this system. The folder defined
echo by the variable %%UGII_BASE_DIR%% does NOT exist.
echo.
echo Please install NX before running %0.

REM added code for success-check
set UG_UPD_ERR_TEXT=Error in UG-Update: No UG installation found in %BASE%.
echo.
goto end_update

:wrong_ug_version 
rem Display error message appropriate for update or patch.
cls
echo.
echo The NX folder defined in the environment variable %%UGII_BASE_DIR%% 
echo appears to be the wrong version. 
echo.
echo %%UGII_BASE_DIR%% is set to: %UGII_BASE_DIR%
echo The detected version is: %NX_REV%
echo.
if %MIN_VERSION% EQU %MAX_VERSION% (
  echo The installed NX version must be: %MIN_VERSION%
) else (
  echo The installed NX version must be within the following range:
  echo Minimum: %MIN_VERSION%  -  Maximum: %MAX_VERSION%
)
echo.
echo Set %%UGII_BASE_DIR%% to the correct folder and re-run %0.
echo.

REM added code for success-check
set UG_UPD_ERR_TEXT=Wrong UG version: %NX_REV%
goto end_update

:wrong_platform
cls
echo.
echo Incorrect machine type for this software. 
echo.
echo This kit contains software intended for %REQUIRED_PLAT% hardware.
echo Check that you are installing the right version of the
echo software for your %ACTUAL_PLAT% hardware.
echo.
goto end_update


:end_update


REM added code for success-check
IF NOT "%UG_UPD_ERR_TEXT%#"=="#" (
 echo Exiting with error
 set ERRORLEVEL=%UG_UPD_ERR_CODE%)
rem exit %UG_UPD_ERR_CODE%

 echo Exiting ...


if not "%D_SWT%" == "/d" pause
@echo on
