@echo off

REM ---------------------------------------------------------------
REM                    Installationsskript
REM ---------------------------------------------------------------
REM
REM Beschreibung:
REM  Skript, das Pakete von einem Server laedt und auf dem lokalen Rechner ausfuehrt.
REM  
REM ---------------------------------------------------------------
REM 
REM Rand-Bedingungen:
REM  - die Parameter/Variablen muessen definiert sein (-> Einstellungen)
REM  - auf Laufwerk E: oder ausweichend D: muss ausreichend Platz sein
REM  - im Falle von UG-Updates darf Unigraphics nicht laufen
REM  
REM ---------------------------------------------------------------
REM 
REM Nebenwirkungen:
REM 
REM  - beim Start aus einem DOS-Fenster wird dieses am Ende geschlossen (wg. EXIT)
REM  - Nach Beendigung bleiben die Logfiles lokal liegen
REM 
REM ---------------------------------------------------------------
REM
REM Moegliche Einstellungen:
REM 
REM   SourceServerFG     
REM     - der Freigabename des Servers, der verwendet werden soll
REM   SourceDir          
REM     - das Unterverzeichnis mit den Paketen die zu installieren sind
REM   startfiles         
REM     - Start-Dateien der Pakete. Werden gestartet und sollen 'ihr' Paket installieren  
REM     - koennen mehrere sein, mit ' ' getrennt
REM     - Pfade relativ zu $SourceDir
REM 
REM   SourceServerAccount
REM   SourceServerPasswd 
REM     - Account/Passwort fuer den Serverzugriff, falls noch keine Verbindung besteht
REM
REM   UG-UPD_tmpdrive    
REM   UG-UPD_tmpdirname  
REM     - in tmpDrive\tmpdirname werden die kopierten Dateien vom Server lokal abgelegt
REM 
REM   UG-UPD_logfile     
REM   UG-UPD_logfileChild
REM     - Namen der Logdateien fuer den Installer und die Paketinstallationen (ging leider nicht in eine Datei)
REM 
REM   UG-UPD_keepCopiedDir
REM   UG-UPD_useExistingDir
REM     - Umgebungsvariablen. Ggf. im Skript oder im Betriebssystem setzen.
REM     - auf "TRUE" setzen, um nach der Installation die vom Server kopierten Pakete zu 
REM       behalten bzw. ein behaltenes Verzeichnis nochmal zu verwenden
REM 
REM ---------------------------------------------------------------


REM ---------------------------------------------------------------
REM    Einstellungen:

set SourceDir=cadinstall\cad-upd-dir
set SourceServerFG=\\fileserver1\cadug
set SourceServerAccount=myDomain\readonlyuser
set SourceServerPasswd=geheim
set startfiles=ug_upd_pk1\start_upd.bat ug_upd_pk2\start_upd.bat
set UG-UPD_tmpdrive=e:
set UG-UPD_tmpdirname=cad-upd-inst.tmp
set UG-UPD_logfile=%TEMP%\ug-upd_inst.log
set UG-UPD_logfileChild=%UG-UPD_logfile%2

REM 
REM ---------------------------------------------------------------

SET UG-UPD_serverState=0
set insterr=0

echo.
echo.
echo.
echo.
echo.
echo.
echo ---------------------------------------------------
echo.
echo   Installation des UG-Updates 'UG NX 2.0.6.2 MP 5'
echo.
echo ---------------------------------------------------
echo.
echo - Starte Installation ...
echo - Starte Installation ... >%UG-UPD_logfile%
echo - Starte Installation ... >%UG-UPD_logfileChild%



echo - Pruefen, ob UG noch laeuft ...
echo - Pruefen, ob UG noch laeuft ... >>%UG-UPD_logfile%
tasklist.exe /FO CSV /NH /FI "IMAGENAME eq ugraf.exe" 2>NUL | find /c "ugraf.exe"  >NUL 2>NUL
IF %ERRORLEVEL% == 0 (
 echo.
 echo.
 echo  /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\
 echo.
 echo             !!!    Fehler    !!!
 echo.
 echo  /\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\/\
 echo.
 echo.
 echo       Unigraphics ist aktiv, ein Update 
 echo          ist parallel nicht moeglich!
 echo.
 echo     Bitte UG beenden und Update neu starten
 echo.
 echo ---------------------------------------------------
 echo  ... raeume auf.
 REM wait some seconds to let the user read the message:
 ping -n 12 localhost >NUL
 set insterr=-15
 goto :errend)
echo - ... kein ugraf.exe laeuft - o.k.
echo - ... kein ugraf.exe laeuft - o.k. >>%UG-UPD_logfile%


echo - Temporaeres Verzeichnis erstellen ...
echo - Temporaeres Verzeichnis erstellen ... >>%UG-UPD_logfile%

IF NOT EXIST "%UG-UPD_tmpdrive%" (
 echo - ... E: existiert nicht, nehme D: stattdessen ...
 echo - ... E: existiert nicht, nehme D: stattdessen ... >>%UG-UPD_logfile%
 set UG-UPD_tmpdrive=d:)
set UG-UPD_tmpdir=%UG-UPD_tmpdrive%^\%UG-UPD_tmpdirname%
echo - ... verwende %UG-UPD_tmpdir% ...
echo - ... verwende %UG-UPD_tmpdir% ... >>%UG-UPD_logfile%

REM Um eine abgebrochene Installation ohne das erneute, zeitaufwaendige Kopieren der Dateien zu erlauben, 
REM die Umgebungsvariable UG-UPD_useExistingDir auf "TRUE" setzen.
IF "%UG-UPD_useExistingDir%"=="TRUE" GOTO :skipCopy

rmdir /q /s  %UG-UPD_tmpdir% >>%UG-UPD_logfile% 2>>&1
mkdir %UG-UPD_tmpdir%        >>%UG-UPD_logfile% 2>>&1
IF NOT %ERRORLEVEL%==0 (
 set insterr=-17
 goto :errend)
echo - ... o.k.
echo - ... o.k. >>%UG-UPD_logfile%

echo - Verbindung mit dem Server herstellen ...
echo - Verbindung mit dem Server herstellen ... >>%UG-UPD_logfile%
IF EXIST "%SourceServerFG%\%SourceDir%" (
 SET UG-UPD_serverState=NoOwnConnect
 echo - ... verwende bestehende Verbindung.
 echo - ... verwende bestehende Verbindung. >>%UG-UPD_logfile%
 GOTO :NoOwnConnect)
net use %SourceServerFG% %SourceServerPasswd% /user:%SourceServerAccount% >>%UG-UPD_logfile%
if not %ERRORLEVEL%==0 (
  set insterr=-18
  goto :errend)
echo - ... o.k.
echo - ... o.k. >>%UG-UPD_logfile%
 :NoOwnConnect

echo - Installationsdaten vom Server kopieren ...
echo -   ... bitte haben Sie Geduld, das KANN laenger dauern ...
echo - Installationsdaten vom Server kopieren ... >>%UG-UPD_logfile%
xcopy /i /e /k /h /r /y  %SourceServerFG%\%SourceDir% %UG-UPD_tmpdir% >> %UG-UPD_logfile% 2>>&1
if not %ERRORLEVEL%==0 (
  set insterr=-19
  goto :errend)
echo -  ... o.k.
echo -  ... o.k. >>%UG-UPD_logfile%


IF NOT %UG-UPD_serverState%==NoOwnConnect (
 echo - Verbindung mit dem Server loesen ...
 echo - Verbindung mit dem Server loesen ... >>%UG-UPD_logfile%
 net use %SourceServerFG% /d >>%UG-UPD_logfile%
 if not %ERRORLEVEL%==0 (
  set insterr=-21
  goto :errend)
 echo -  ... o.k.
 echo -  ... o.k. >>%UG-UPD_logfile%)


:skipCopy

echo - Pakete installieren ...
echo - Pakete installieren ... >>%UG-UPD_logfile%
for %%K in (%startfiles%) do call :SUB_install_paket %%K
IF NOT %insterr%==0 (
 set insterr=-23
 echo - ... Paketinstallation abgebrochen.
 echo - ... Paketinstallation abgebrochen. >>%UG-UPD_logfile%
 goto :errend)
echo - Alle Pakete installiert.
echo - Alle Pakete installiert. >>%UG-UPD_logfile%


IF "%UG-UPD_useExistingDir%"=="TRUE" GOTO :skipDelete
IF "%UG-UPD_keepCopiedDir%"=="TRUE" GOTO :skipDelete

echo - Temporaere Dateien loeschen ...
echo - Temporaere Dateien loeschen ... >>%UG-UPD_logfile%
rmdir /q /s  %UG-UPD_tmpdir% >>%UG-UPD_logfile% 2>>&1
if not %ERRORLEVEL%==0 set insterr=-25
if not %ERRORLEVEL%==0 goto :errend
echo -  ... o.k.
echo -  ... o.k. >>%UG-UPD_logfile%

:skipDelete

goto :end

:errend
echo - Beende mit Fehler %insterr%!
echo - Beende mit Fehler %insterr%! >>%UG-UPD_logfile%
echo ----------------------------------------------
exit %insterr%

:end
echo - Installation erfolgreich durchgefuehrt !
echo - Installation erfolgreich durchgefuehrt ! >>%UG-UPD_logfile%
echo ----------------------------------------------
exit 0



REM Sub: run each package
:SUB_install_paket

  set paketname=%UG-UPD_tmpdir%\%1%
  if not defined paketname goto :EOF
  echo -  o Paket %paketname% installieren ...
  echo -  o Paket %paketname% installieren ... >>%UG-UPD_logfile%

  REM check if the package exists
  IF NOT EXIST %paketname% (
    set insterr=-117
    echo -    ... NICHT gefunden.
    echo -    ... NICHT gefunden. >> %UG-UPD_logfile%
    goto :EOF)
  echo -    ... gefunden ...
  echo -    ... gefunden ... >> %UG-UPD_logfile%

  REM run the package
  call %paketname% 1>> %UG-UPD_logfileChild% 2>>&1
  @REM ugs_update.bat set echo on again -> switch it off after this if
  @REM      (_after_ it, to preserve the ERRORLEVEL from the package run), use @ to avoid echoes of the lines
  @if not %ERRORLEVEL%==0 (
    @set insterr=%ERRORLEVEL%
    @echo off
    @goto :EOF)
  @echo off
  echo -    ... o.k.
  echo -    ... o.k. >>%UG-UPD_logfile%

goto :EOF
REM end of sub
